{$INCLUDE ..\cDefines.inc}
unit cControls;

interface

uses
  { Delphi }
  Graphics,
  Classes,
  Controls,
  Menus,
  ComCtrls;



{ TControl                                                                     }
var
  EnabledEditColor  : TColor = clWindow;
  DisabledEditColor : TColor = clBtnFace;

function  GetEditColor(const Enabled: Boolean): TColor;
function  GetTextColor(const Enabled: Boolean): TColor;
procedure SetCtrlEnabled(const Control: TControl; const Enabled: Boolean);



{ TTreeNode                                                                    }
function  LocateChildNodeByData(const Parent: TTreeNode; const Data: Pointer): TTreeNode;



{ TMenuItem                                                                    }
function  CreateMenuItem(const Owner: TComponent; const Caption: String;
          const OnClick: TNotifyEvent = nil; const Tag: Integer = 0) : TMenuItem;


{ TRichEdit                                                                    }
procedure AddRichEditColLine(const R: TCustomRichEdit; const Line: String;
          const Color: TColor = clBlack);



implementation

uses
  { Delphi }
  Windows,
  Messages,
  StdCtrls;



{ TControl                                                                     }
function GetEditColor(const Enabled: Boolean): TColor;
begin
  if Enabled then
    Result := EnabledEditColor else
    Result := DisabledEditColor;
end;

function GetTextColor(const Enabled: Boolean): TColor;
begin
  if Enabled then
    Result := clWindowText else
    Result := clGrayText;
end;

procedure SetCtrlEnabled(const Control: TControl; const Enabled: Boolean);
var I : Integer;
begin
  Control.Enabled := Enabled;
  if Control is TEdit then
    TEdit(Control).Color := GetEditColor(Enabled) else
  if Control is TComboBox then
    TComboBox(Control).Color := GetEditColor(Enabled) else
  if Control is TGroupBox then
    TGroupBox(Control).Font.Color := GetTextColor(Enabled);
  if Control is TWinControl then
    For I := 0 to TWinControl(Control).ControlCount - 1 do
      SetCtrlEnabled(TWinControl(Control).Controls[I], Enabled);
end;



{ TTreeNode                                                                    }
function LocateChildNodeByData(const Parent: TTreeNode; const Data: Pointer): TTreeNode;
var M : TTreeNode;
begin
  if Assigned(Parent) then
    begin
      M := Parent.GetFirstChild;
      While Assigned(M) do
        if M.Data = Data then
          begin
            Result := M;
            exit;
          end else
          M := Parent.GetNextChild(M);
    end;
  Result := nil;
end;


{ TMenuItem                                                                    }
function CreateMenuItem(const Owner: TComponent; const Caption: String;
    const OnClick: TNotifyEvent; const Tag: Integer): TMenuItem;
begin
  Result := TMenuItem.Create(Owner);
  Result.Caption := Caption;
  Result.OnClick := OnClick;
  Result.Tag := Tag;
end;


{ TRichEdit                                                                    }
procedure AddRichEditColLine(const R: TCustomRichEdit; const Line: String;
    const Color: TColor);
var L : Integer;
    S : String;
begin
  L := R.Perform(WM_GETTEXTLENGTH, 0, 0);
  R.SelStart := L;
  R.SelLength := 0;
  R.SelAttributes.Color := Color;
  if L > 0 then
    S := #13#10 + Line else
    S := Line;
  R.SelText := S;
  R.Perform(EM_LineScroll, 0, R.Lines.Count - 1);
end;



end.

